@@ -1,4 +1,13 @@
-from ._version import __version__
+try:
+    from importlib.metadata import version, PackageNotFoundError
+except ImportError:
+    from importlib_metadata import version, PackageNotFoundError
+
+try:
+    __version__ = version("healsparse")
+except PackageNotFoundError:
+    # package is not installed
+    pass
 
 from .healSparseMap import HealSparseMap
 from .healSparseCoverage import HealSparseCoverage
